@@ -21,25 +21,24 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "0.15"
+VERSION    = "2.11.90"
 DATADIR    = "/gnome/head/INSTALL/share"
 SYSCONFDIR = "/gnome/head/INSTALL/etc"
 LIBEXECDIR = "/gnome/head/INSTALL/libexec"
 SBINDIR    = "/gnome/head/INSTALL/sbin"
 
-PKGDATADIR  = os.path.join (DATADIR, "sabayon")
+GLADEDIR    = os.path.join (DATADIR, "sabayon", "glade")
 PROFILESDIR = os.path.join (SYSCONFDIR, "desktop-profiles")
 
-SESSION_TOOL_ARGV = [ os.path.join (LIBEXECDIR, "sabayon-session") ]
 MONITOR_TOOL_ARGV = [ os.path.join (LIBEXECDIR, "sabayon-monitor") ]
+SESSION_TOOL_ARGV = [ os.path.join (LIBEXECDIR, "sabayon-session") ]
 APPLY_TOOL_ARGV   = [ os.path.join (SBINDIR,    "sabayon-apply") ]
 
 # FIXME: this is too big a hammer
 CLOBBER_USER_PROCESSES_ARGV = [ "/usr/bin/pkill", "-u" ]
 
-# No. of seconds to wait after the session has started before
-# running the monitor tool
-ADMIN_TOOL_TIMEOUT = 3
+# No. of seconds to wait for USR1 from Xnest before giving up
+XNEST_USR1_TIMEOUT = 10
 
 #
 # This is the user which we run the prototype sessions
@@ -73,51 +72,50 @@ PASSTHROUGH_ENVIRONMENT = [
     "LC_TIME",
     "LC_NUMERIC",
     "LC_MONETARY",
-    "LC_MESSAGES"
+    "LC_MESSAGES",
+    "METACITY_VERBOSE",
+    "METACITY_USE_LOGFILE"
 ]
 
 #
-# Files a directories which we don't want to see change
-# notifications for
+# Files which we don't want to see change notifications for
 #
 FILES_TO_IGNORE = [
-    ".xsession-errors",
+    ".ICEauthority*",
+    ".fonts.cache-1*",
+    ".gconf.path.defaults",
+    ".gconf.path.defaults.new",
+    ".gconf.path.mandatory",
+    ".gconf.path.mandatory.new",
     ".gnome/gnome-vfs/.trash_entry_cache",
+    ".gnome2/share/cursor-fonts/fonts.dir",
     ".gnome2/share/fonts/fonts.dir",
-    ".gnome2/share/cursor-fonts/fonts.dir"
+    ".gtkrc-1.2-gnome2*",
+    ".recently-used",
+    ".xsession-errors"
 ]
 
+#
+# Directories which we don't want to see change notifications for
+# 
 DIRECTORIES_TO_IGNORE = [
-    ".metacity/sessions",
     ".gconf",
     ".gconf.xml.defaults",
     ".gconf.xml.mandatory",
     ".gconfd",
-    ".nautilus/metafiles"
+    ".gstreamer-0.8",
+    ".metacity/sessions",
+    ".nautilus/metafiles",
+    ".profile_cache",
+    ".thumbnails"
 ]
 
-try:
-    GLADEDIR = os.environ["GLADEDIR"]
-except:
-    if os.path.exists ("sabayon.glade"):
-        GLADEDIR ="./"
-    elif os.path.exists ("admin-tool/sabayon.glade"):
-        GLADEDIR = "admin-tool"
-    elif os.path.exists (os.path.join (PKGDATADIR, "glade/sabayon.glade")):
-        GLADEDIR = os.path.join (PKGDATADIR, "glade")
-    else:
-        GLADEDIR = "./"
-
-try:
-    MODULEPATH = os.environ["MODULEPATH"]
-except:
-    if os.path.exists ("sources"):
-        MODULEPATH = "sources"
-    elif os.path.exists ("lib/sources"):
-        MODULEPATH = "lib/sources"
-    elif os.path.exists ("../lib/sources"):
-        MODULEPATH = "../lib/sources"
-    elif os.path.exists (os.path.join (PKGDATADIR, "sources")):
-        MODULEPATH = os.path.join (PKGDATADIR, "sources")
-    else:
-        MODULEPATH = "sources"
+#
+# GConf keys which we don't want to see change notifications for
+#
+GCONF_KEYS_TO_IGNORE = [
+    "/apps/nautilus/preferences_version",
+    "/apps/nautilus/sound_state",
+    "/apps/panel/general/profiles_migrated"
+    "/desktop/gnome/peripherals/keyboard/kbd.sysbackup/*",
+]
