@@ -19,10 +19,16 @@
 #
 
 import gconf
-import userprofile
 import gconfsource
-import util
-from config import *
+
+try:
+    import userprofile
+    import util
+    from config import *
+except:
+    from sabayon import userprofile
+    from sabayon import util
+    from sabayon.config import *
 
 def dprint (fmt, *args):
     util.debug_print (util.DEBUG_PANELDELEGATE, fmt % args)
@@ -118,15 +124,25 @@ class PanelDelegate (userprofile.SourceDelegate):
         self.__read_panel_config ()
 
     def __read_panel_config (self):
+        dprint ("Reading initial panel config");
+        
+        dprint ("Toplevels:");
         for id in self.client.get_list (PANEL_KEY_BASE + "/general/toplevel_id_list", gconf.VALUE_STRING):
             if not self.toplevels.has_key (id):
-                self.toplevels[id] = PanelDelegate.PanelToplevel (id, False)
+                dprint ("  %s", id);
+                self.toplevels[id] = PanelDelegate.PanelToplevel (id)
+                
+        dprint ("Applets:");
         for id in self.client.get_list (PANEL_KEY_BASE + "/general/applet_id_list", gconf.VALUE_STRING):
             if not self.applets.has_key (id):
-                self.applets[id] = PanelDelegate.PanelApplet (id, False)
+                dprint ("  %s", id);
+                self.applets[id] = PanelDelegate.PanelApplet (id)
+                
+        dprint ("Objects:");
         for id in self.client.get_list (PANEL_KEY_BASE + "/general/object_id_list", gconf.VALUE_STRING):
             if not self.objects.has_key (id):
-                self.objects[id] = PanelDelegate.PanelObject (id, False)
+                dprint ("  %s", id);
+                self.objects[id] = PanelDelegate.PanelObject (id)
 
     def __handle_id_list_change (self, change, dict, thing_class, added_class, removed_class):
         if not change.value or \
@@ -157,6 +173,9 @@ class PanelDelegate (userprofile.SourceDelegate):
                 dict[id].removed = True
                 removed.append (id)
 
+        dprint ("%s changed: (%s) added, (%s) removed\n",
+                change.key, added, removed);
+
         for id in added:
             self.source.emit ("changed", added_class (self.source, self, id))
         for id in removed:
@@ -300,6 +319,20 @@ class PanelDelegate (userprofile.SourceDelegate):
                                           "object_id_list",
                                           "objects")
 
+    def start_monitoring (self):
+        """Start monitoring for configuration changes."""
+        # Nothing to do here
+        pass
+
+    def stop_monitoring (self):
+        """Stop monitoring for configuration changes."""
+        # Nothing to do here
+        pass
+
+    def sync_changes (self):
+        # Nothing to do here
+        pass
+    
     def apply (self):
         # Nothing to do here
         pass
