@@ -25,9 +25,12 @@ import pwd
 import gettext
 import locale
 import errno
+import warnings
+import exceptions
 from config import *
 
 (
+    DEBUG_DEPRECATED,
     DEBUG_USERPROFILE,
     DEBUG_STORAGE,
     DEBUG_PROTOSESSION,
@@ -40,9 +43,10 @@ from config import *
     DEBUG_ADMINTOOL,
     DEBUG_USERDB,
     DEBUG_CACHE,
-) = range (12)
+) = range (13)
 
 debug_modules = {
+    DEBUG_DEPRECATED    : ("deprecated",     False),
     DEBUG_USERPROFILE   : ("user-profile",   False),
     DEBUG_STORAGE       : ("storage",        False),
     DEBUG_PROTOSESSION  : ("proto-session",  False),
@@ -60,6 +64,7 @@ debug_modules = {
 def init_debug_modules ():
     debug_value = os.getenv ("SABAYON_DEBUG")
     if not debug_value:
+        warnings.filterwarnings ("ignore", category = exceptions.DeprecationWarning)
         return
 
     if debug_value == "help":
@@ -77,15 +82,17 @@ def init_debug_modules ():
         for item in debug_value.split (":"):
             item = item.split("=")
             key = item[0]
+            value = True
             if len(item) > 1:
                 value = int(item[1],16)
-            else:
-                value = ~0
             for module in debug_modules:
                 if debug_modules[module][0] == key:
                     debug_modules[module] = (key, value)
                     break
 
+    if not debug_modules[DEBUG_DEPRECATED][1]:
+        warnings.filterwarnings ("ignore", category = exceptions.DeprecationWarning)
+
 init_debug_modules ()
 
 def debug_print (module, message, mask=~0):
@@ -144,6 +151,45 @@ def init_gettext ():
     locale.setlocale (locale.LC_ALL, "")
     gettext.install (PACKAGE, os.path.join (DATADIR, "locale"))
 
+def split_path(path, head=None, tail=None):
+    '''Given a path split it into a head and tail. If head is passed then
+    it is assumed to comprise the first part of the full path. If tail is
+    passed it is assumed to comprise the second part of the full path.
+    The path, head, and tail are made canonical via os.path.normpath prior
+    to the operations. ValueErrors are raised if head is not present at the
+    start of the path or if the path does not end with tail. The split must
+    occur on a directory separator boundary.
+
+    The return value is the tuple (head, tail) in canonical form.'''
+    path = os.path.normpath(path)
+
+    if tail is not None:
+        tail = os.path.normpath(tail)
+        if tail[0] == '/':
+            tail = tail[1:]
+        if not path.endswith(tail):
+            raise ValueError
+        path_len = len (path)
+        tail_len = len (tail)
+        dir_split = path_len - tail_len - 1
+        if path[dir_split] != '/':
+            raise ValueError
+        return (path[:dir_split], path[dir_split+1:])
+
+    if head is not None:
+        head = os.path.normpath(head)
+        if head[-1] == '/':
+            head = head[:-1]
+        if not path.startswith(head):
+            raise ValueError
+        head_len = len (head)
+        dir_split = head_len
+        if path[dir_split] != '/':
+            raise ValueError
+        return (path[:dir_split], path[dir_split+1:])
+        
+    raise ValueError
+
 #
 # os.spawn() doesn't handle EINTR from waitpid() on Linux:
 #  http://sourceforge.net/tracker/?group_id=5470&atid=105470&func=detail&aid=686667
@@ -156,7 +202,7 @@ def uninterruptible_spawnve (mode, file, args, env):
             os.spawnv (mode, file, args)
         else:
             os.spawnve (mode, file, args, env)
-    except os.error, (err, str):
+    except os.error, (err, errstr):
         if err != errno.EINTR:
             raise
         
